@@ -1,16 +1,23 @@
 #' @title Attribution when publishing GISCO data
-#' @description Get the legal text to be used along with the data downloaded with this package
-#' @param lang Language (two-letter \href{https://en.wikipedia.org/wiki/List_of_ISO_639-1_codes}{ISO_639-1} code). See details.
-#' @param copyright Boolean. Whether to display the copyright notice or not on the console.
+#' @description Get the legal text to be used along with the data
+#' downloaded with this package
+#' @param lang Language (two-letter
+#' \href{https://en.wikipedia.org/wiki/List_of_ISO_639-1_codes}{ISO_639-1}
+#' code). See details.
+#' @param copyright Boolean. Whether to display the copyright notice or
+#' not on the console.
 #' @return A string with the attribution to be used.
-#' @details Current languages supported are "en" (English), "da" (Danish), "de" (German),
-#' "es" (Spanish), "fi" (Finish), "fr" (French), "no" (Norwegian) and "sv" (Swedish).
+#' @details Current languages supported are "en" (English), "da"
+#' (Danish), "de" (German),
+#' "es" (Spanish), "fi" (Finish), "fr" (French), "no" (Norwegian) and
+#'  "sv" (Swedish).
 #'
 #' Consider contributing if you spot any mistake or want to add a new language.
 #'
 #' @note COPYRIGHT NOTICE
 #'
-#' When data downloaded from \href{https://ec.europa.eu/eurostat/web/gisco/geodata/reference-data/administrative-units-statistical-units}{this page}
+#' When data downloaded from
+#'  \href{https://ec.europa.eu/eurostat/web/gisco/geodata/reference-data/administrative-units-statistical-units}{this page}
 #' is used in any printed or electronic publication,
 #' in addition to any other provisions
 #' applicable to the whole Eurostat website,
@@ -89,7 +96,7 @@ gisco_attributions <- function(lang = "en", copyright = FALSE) {
     attr <-
       "\u00a9 EuroGeographics f\u00f6r administrativa gr\u00e4nser"
   } else {
-    print("This language is not supported, switching to English. Consider contributing")
+    print("Language not supported, switching to English. Consider contributing")
     attr <-
       "\u00a9 EuroGeographics for the administrative boundaries"
   }
